<?php 
/**
 * Product Section
 * @since 1.0.0
 * ----------------------------------------------------------------------
 */
	$wp_customize->add_section( 'product_section_settings',
		array(
			'title'       => esc_html__( 'Products Section', 'bizindustries' ),
			'description' => '',
			'panel'       => 'bizindustries_frontpage_settings',
			'priority' => 2,
			'divider' => 'before',
		)
	);
		$wp_customize->add_setting( 'products_section_enable', 
			array(
			  'default'  =>  false,
			  'sanitize_callback' => 'bizindustries_sanitize_checkbox',
			)
		);
		$wp_customize->add_control( 'products_section_enable', 
			array(
			  'label'         => esc_html__( 'Show/hide Products Section', 'bizindustries' ),
			  'description'   => esc_html__( 'Check/Uncheck this box to show/hide products section on front page.', 'bizindustries' ),
			  'section'       => 'product_section_settings',
			  'settings'      => 'products_section_enable',
			  'type'          => 'checkbox',
			  'priority'      => 1
			)
		);

		//Section Heading
		$wp_customize->add_setting( 'products_title', 
			array(
				'default'           => esc_html__('Our Products', 'bizindustries'),
				'sanitize_callback' => 'sanitize_text_field',
				'transport'         => 'postMessage'
			) 
		);
		$wp_customize->add_control( 'products_title', 
			array(
			    'label'   => esc_html__( 'Section Heading', 'bizindustries' ),
				'section' => 'product_section_settings',
				'type'    => 'text',
				'active_callback' => function(){
					 $products_enable = get_theme_mod('products_section_enable');
					 if($products_enable){
						return true;
					 } else {
						 return false;
					 }
				},
				'priority'=> 2,
			) 
		);

		// Section subheading
		$wp_customize->add_setting( 'products_subtitle', 
			array(
				'default'           => esc_html__('Explore', 'bizindustries'),
				'sanitize_callback' => 'sanitize_text_field',
				'transport'         => 'postMessage'
			) 
		);
		$wp_customize->add_control( 'products_subtitle', 
			array(
			'label'      => esc_html__('Section Subheading', 'bizindustries'),
				'description'=> '',
				'section'    => 'product_section_settings',
				'type'       => 'text',
				'active_callback' => function(){
					 $products_enable = get_theme_mod('products_section_enable');
					 if($products_enable){
						return true;
					 } else {
						 return false;
					 }
				},
				'priority' => 3,
			)
		);
		
		// Section Description
		$wp_customize->add_setting( 'products_description', 
			array(
				'default'           => esc_html__('Top quality services executed by our devoted, yet creative team. We are focused on making you stand out.', 'bizindustries'),
				'sanitize_callback' => 'sanitize_textarea_field',
				'transport'         => 'postMessage'
			) 
		);
		$wp_customize->add_control( 'products_description', 
			array(
				'label'      => esc_html__('Section Description', 'bizindustries'),
				'description'=> '',
				'section'    => 'product_section_settings',
				'type'       => 'textarea',
				'active_callback' => function(){
					 $products_enable = get_theme_mod('products_section_enable');
					 if($products_enable){
						return true;
					 } else {
						 return false;
					 }
				},
				'priority' => 3,
			)
		);
		$is_premium = bizindustries_set_to_premium(); 
		// Products
		$wp_customize->add_setting( 
			new Bizindustries_Control_Repeater_Setting( 
				$wp_customize, 
				'bizindustries_products', 
				array(
					'default' => '',
					'sanitize_callback' => array( 'Bizindustries_Control_Repeater_Setting', 'sanitize_repeater_setting' ),
				) 
			) 
		);
		$wp_customize->add_control(
			new Bizindustries_Control_Repeater(
				$wp_customize,
				'bizindustries_products',
				array(
					'section'       => 'product_section_settings',
					'label'         => esc_html__( 'Prodcuts', 'bizindustries' ),
					'fields'  => array(

						'title' => array(
							'type'        => 'text',
							'label'       => esc_html__( 'Title', 'bizindustries' ),
						),
						'description' => array(
							'type'        => 'textarea',
							'label'       => esc_html__( 'Descrition', 'bizindustries' ),
						),
						'btn_text' => array(
							'type'        => 'text',
							'label'       => esc_html__( 'Button Text', 'bizindustries' ),
						),
						'link' => array(
							'type'        => 'url',
							'label'       => esc_html__( 'Link', 'bizindustries' ),
							'description' => esc_html__( 'Example: https://yourstie.com', 'bizindustries' ),
						),
						'checkbox' => array(
							'type'        => 'checkbox',
							'label'       => esc_html__( 'Open link in new tab', 'bizindustries' ),
						),
						'image' => array(
							'type'    => 'image',
							'label'   => __( 'Upload Product Image', 'bizindustries' ),
						),
					),
					'row_label' => array(
						'type'  => 'field',
						'value' => esc_html__( 'Product', 'bizindustries' ),
						'field' => 'title'
					),
					'choices' => array(
						'limit' => $is_premium==false?3:'',
					),
					'active_callback' => function(){
						 if( get_theme_mod('products_section_enable') ){
							return true;
						 } else {
							 return false;
						 }
					},
				)
			)
		);
		
		// Background color
		$wp_customize->add_setting( 'products_section_bg', 
			array(
					'sanitize_callback'    => 'sanitize_hex_color_no_hash',
					'sanitize_js_callback' => 'maybe_hash_hex_color',
					'default'              => '',
				) 
			);
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'products_section_bg', 
			array(
				'label' => esc_html__( 'Background', 'bizindustries' ),
				'description'   => '',
				'section' => 'product_section_settings',
				'active_callback' => function(){
					 if(get_theme_mod('products_section_enable')){
						return true;
					 } else {
					 return false;
					 }
				},
			) ) 
		);
		
		
		